@@ -72,10 +72,15 @@ class ZIDS_Tester:
         model_request = self.create_model_request(batch_of_pages)
 
         # Call the model to get predictions
-        predicted_records = self.pipeline.execute(model_request)
-
+        predicted_records = self.pipeline.execute(**model_request)
+        parsed_row_data_frame = {}
+        for title in row_dataframe.columns[1:]:
+            parsed_row_data_frame[title] = row_dataframe.iloc[0][title]
+        pred_tmp = {'pred_model' : json.dumps(predicted_records.dict()),
+                    'target': json.dumps(parsed_row_data_frame)
+                    }
         if predicted_records:
-            df_predicted = self.create_predicted_records_dataframe(predicted_records)
+            df_predicted = self.create_predicted_records_dataframe(pred_tmp)
             row_dataframe = row_dataframe.join(df_predicted)
         else:
             # we did not get any records, create empty records
@@ -112,7 +117,7 @@ class ZIDS_Tester:
             df_predicted: DataFrame
         """
 
-        df_predicted = pd.DataFrame(predicted_records)
+        df_predicted = pd.DataFrame(predicted_records, index=[0])
         df_predicted = df_predicted.rename(columns={self.pred_name: 'pred_model'})
         return df_predicted
 
