@@ -41,7 +41,9 @@ class Workflow(ZIDS_Workflow):
         stage_dir = f'batch_files/stages/{stage_name}'
         python_files = [self.whl_pipes_file_name,
                         self.whl_no_pipes_file_name]
-        stage_job = self.create_ordered_job(stage_dir, self.spark_properties, python_files)
+        archive_files = [self.whl_pipes_file_name,
+                         self.whl_no_pipes_file_name]
+        stage_job = self.create_ordered_job(stage_dir, self.spark_properties, python_files, archive_files)
 
         if prerequisite_list is not None:
             stage_job.prerequisite_step_ids = prerequisite_list
