@@ -174,17 +174,37 @@ class generatedClass(ZIDS_Tester):
         ## Define ground truth column name
         ground_truth_col_name = self.target_name
 
+        # Load CSV. predictions and ground truth columns are converted from string to list/dict
+        df = pd.read_csv(csv_file_path,
+                         converters={predictions_col_name: json.loads,
+                                     ground_truth_col_name: json.loads})
+
+        self.run_test(df, batch_size)
+
+    def test_from_dataset(self, dataset, batch_size):
+        """! Run an evaluation from a csv file input.
+
+        Args:
+            csv_file_path: csv file containing both ground truth and raw input for the model.
+            batch_size: Size of batch to use in order to feed the model with controllable chunks of data
+        """
+        df = dataset
+        csv_output_path = self.run_test(df, batch_size)
+        return csv_output_path
+
+    def run_test(self, df, batch_size):
+        """! Run an evaluation from a csv file input.
+
+        Args:
+            csv_file_path: csv file containing both ground truth and raw input for the model.
+            batch_size: Size of batch to use in order to feed the model with controllable chunks of data
+        """
         # Define csv output
         time_str = get_date_time(False, True)
         csv_output_name = "model_eval_results_" + time_str + ".csv"
         csv_output_path = os.path.join(os.getcwd(), csv_output_name)
         first_chunk = True
 
-        # Load CSV. predictions and ground truth columns are converted from string to list/dict
-        df = pd.read_csv(csv_file_path,
-                         converters={predictions_col_name: json.loads,
-                                     ground_truth_col_name: json.loads})
-
         # Chunk according to batch size
         batches = split_dataframe(df, int(batch_size))
 
@@ -214,6 +234,7 @@ class generatedClass(ZIDS_Tester):
             else:
                 df_model_evaluation_results.to_csv(csv_output_path, mode='a', header=False)
 
+        return csv_output_path
 
 # This will call the tester with a given csv file
 if __name__ == '__main__':
